[−][src]Module muta_protocol::codec
Modules
| epoch | |
| primitive | |
| receipt | |
| transaction |
Enums
| CodecError |
Traits
| Deserialize | A data structure that can be deserialized from any data format supported by Serde. |
| ProtocolCodec | |
| Serialize | A data structure that can be serialized into any data format supported by Serde. |
Derive Macros
| Deserialize | |
| Serialize |