pub struct RawTransaction {
pub chain_id: Option<Hash>,
pub nonce: Option<Hash>,
pub timeout: u64,
pub cycles_price: u64,
pub cycles_limit: u64,
pub request: Option<TransactionRequest>,
}Fields
chain_id: Option<Hash>nonce: Option<Hash>timeout: u64cycles_price: u64cycles_limit: u64request: Option<TransactionRequest>Trait Implementations
Sourceimpl Clone for RawTransaction
impl Clone for RawTransaction
Sourcefn clone(&self) -> RawTransaction
fn clone(&self) -> RawTransaction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RawTransaction
impl Debug for RawTransaction
Sourceimpl Default for RawTransaction
impl Default for RawTransaction
Sourcefn default() -> RawTransaction
fn default() -> RawTransaction
Returns the “default value” for a type. Read more
Sourceimpl From<RawTransaction> for RawTransaction
impl From<RawTransaction> for RawTransaction
Sourcefn from(raw: RawTransaction) -> RawTransaction
fn from(raw: RawTransaction) -> RawTransaction
Converts to this type from the input type.
Sourceimpl Message for RawTransaction
impl Message for RawTransaction
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl TryFrom<RawTransaction> for RawTransaction
impl TryFrom<RawTransaction> for RawTransaction
Sourcetype Error = ProtocolError
type Error = ProtocolError
The type returned in the event of a conversion error.
Sourcefn try_from(raw: RawTransaction) -> Result<RawTransaction, Self::Error>
fn try_from(raw: RawTransaction) -> Result<RawTransaction, Self::Error>
Performs the conversion.