pub struct SignedTransaction {
pub raw: Option<RawTransaction>,
pub tx_hash: Option<Hash>,
pub pubkey: Vec<u8>,
pub signature: Vec<u8>,
}Fields
raw: Option<RawTransaction>tx_hash: Option<Hash>pubkey: Vec<u8>signature: Vec<u8>Trait Implementations
Sourceimpl Clone for SignedTransaction
impl Clone for SignedTransaction
Sourcefn clone(&self) -> SignedTransaction
fn clone(&self) -> SignedTransaction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SignedTransaction
impl Debug for SignedTransaction
Sourceimpl Default for SignedTransaction
impl Default for SignedTransaction
Sourcefn default() -> SignedTransaction
fn default() -> SignedTransaction
Returns the “default value” for a type. Read more
Sourceimpl From<SignedTransaction> for SignedTransaction
impl From<SignedTransaction> for SignedTransaction
Sourcefn from(stx: SignedTransaction) -> SignedTransaction
fn from(stx: SignedTransaction) -> SignedTransaction
Converts to this type from the input type.
Sourceimpl Message for SignedTransaction
impl Message for SignedTransaction
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl TryFrom<SignedTransaction> for SignedTransaction
impl TryFrom<SignedTransaction> for SignedTransaction
Sourcetype Error = ProtocolError
type Error = ProtocolError
The type returned in the event of a conversion error.
Sourcefn try_from(stx: SignedTransaction) -> Result<SignedTransaction, Self::Error>
fn try_from(stx: SignedTransaction) -> Result<SignedTransaction, Self::Error>
Performs the conversion.